@@ -107,7 +107,6 @@ class tagObject(object):
         self.__foundPhrase = ''
         self.__foundDict = {}
         self.__ConTextCategory = ConTextCategory
-        self.__category = self.__item.getCategory()
         self.__tagID = tagid
         if( scope == None ):
             self.__scope = []
@@ -141,7 +140,7 @@ class tagObject(object):
         update the scope of self
         returns True if a obj modified the scope of self"""
         if( not self.getRule() or self.getRule()== 'terminate' or
-             (self.getCategory() != obj.getCategory() and obj.getRule() != 'terminate')):
+             (not self.isA(obj.getCategory()) and obj.getRule() != 'terminate')):
             return False
         originalScope = copy.copy((self.getScope()))
         if( 'forward' in self.getRule().lower() or
@@ -182,9 +181,15 @@ class tagObject(object):
         return self.__item.getLiteral()
     def getCategory(self):
         """returns the category (e.g. CONJUNCTION) for this object"""
-        return self.__category
+        return self.__item.getCategory()
+    def categoryString(self):
+        return self.__item.categoryString()
+    def isA(self,category):
+        return self.__item.isA(category)
     def setCategory(self,category):
-        self.__category = category
+        self.__item.__category = category
+    def replaceCategory(self,oldCategory,newCategory):
+        self.__item.replaceCategory(oldCategory,newCategory)
     def setSpan(self,span):
         """set the span within the associated text for this object"""
         self.__spanStart = span[0]
@@ -608,7 +613,7 @@ class ConTextMarkup(nx.DiGraph):
             self.add_nodes_from(self.markItem(item, ConTextMode=mode), category=mode)
 
 
-    def markItem(self,item, ConTextMode="target", ignoreCase=True ):
+    def markItem(self,item, ConTextMode="target", ignoreCase=True):
         """
         markup the current text with the current item.
         If ignoreCase is True (default), the regular expression is compiled with
@@ -622,8 +627,12 @@ class ConTextMarkup(nx.DiGraph):
         if(not compiledRegExprs.has_key(item.getLiteral()) ):
             if(not item.getRE()):
                 regExp = ur"\b%s\b"%item.getLiteral()
+                if( self.getVerbose() ):
+                    print "generating regular expression",regExp
             else:
                 regExp = item.getRE()
+                if( self.getVerbose() ):
+                    print "using provided regular expression",regExp
             if( ignoreCase ):
                 r = re.compile(regExp, re.IGNORECASE|re.UNICODE)
             else:
@@ -650,7 +659,7 @@ class ConTextMarkup(nx.DiGraph):
         prune Marked objects by deleting any objects that lie within the span of
         another object. Currently modifiers and targets are treated separately
         """
-        self.__prune_marks(self.nodes())
+        self.__prune_marks(self.nodes(data=True))
     def dropInactiveModifiers(self):
         mnodes = [ n for n in self.getConTextModeNodes("modifier") if self.degree(n) == 0]
         if( self.getVerbose() and mnodes ):
@@ -682,13 +691,13 @@ class ConTextMarkup(nx.DiGraph):
         nodesToRemove = []
         for i in range(len(marks)-1):
             t1 = marks[i]
-            if( t1 not in nodesToRemove ):
+            if( t1[0] not in nodesToRemove ):
                 for j in range(i+1,len(marks)):
                     t2 = marks[j]
-                    if( t1.encompasses(t2) ):
-                        nodesToRemove.append(t2)
-                    elif( t2.encompasses(t1) ):
-                        nodesToRemove.append(t1)
+                    if( t1[0].encompasses(t2[0]) and t1[1]['category'] == t2[1]['category'] ):
+                        nodesToRemove.append(t2[0])
+                    elif( t2[0].encompasses(t1[0]) and t2[1]['category'] == t1[1]['category'] ):
+                        nodesToRemove.append(t1[0])
                         break
         if( self.getVerbose() ):
             print u"pruning the following nodes"
@@ -701,8 +710,8 @@ class ConTextMarkup(nx.DiGraph):
         if( self.getVerbose() ):
             print "in dropMarks"
             for n in self.nodes():
-                print n.getCategory().lower(),n.getCategory().lower() == category.lower()
-        dnodes = [n for n in self.nodes() if n.getCategory().lower() == category.lower()]
+                print n.getCategory(),n.isA(category.lower())
+        dnodes = [n for n in self.nodes() if n.isA( category )]
         if( self.getVerbose() and dnodes ):
             print u"droping the following markedItems"
             for n in dnodes:
@@ -752,20 +761,21 @@ class ConTextMarkup(nx.DiGraph):
         """
         pred = self.getModifiers(node )
         for p in pred:
-            if( queryCategory.lower() == p.getCategory().lower() ):
+            #if( queryCategory.lower() == p.getCategory().lower() ):
+            if( p.isA(queryCategory) ):
                 return True
 
         return False
-    def isModifiedBy(self, node, query):
-        """
-        Tests whether node in markUp is modified by any tagObjects with category including query. This does not need to be an exact match. Thus "probable" will match "probable_existence" and "probable_negated_existence"
-        """
-        pred = self.getModifiers(node)
-        q = query.lower()
-        for p in pred:
-            if( q in p.getCategory().lower() ):
-                return True
-        return False
+#    def isModifiedBy(self, node, query):
+        #"""
+        #Tests whether node in markUp is modified by any tagObjects with category including query. This does not need to be an exact match. Thus "probable" will match "probable_existence" and "probable_negated_existence"
+        #"""
+        #pred = self.getModifiers(node)
+        #q = query.lower()
+        #for p in pred:
+            #if( q in p.getCategory().lower() ):
+                #return True
+        #return False
 
     def getTokenDistance(self,n1,n2):
         """returns the number of tokens (word) between n1 and n2"""
